<?php
/**
* 2007-2020 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2020 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

require_once 'src/apiRegion.php';
require_once 'src/apiComuna.php';
require_once 'src/apiAnulacion.php';
require_once 'src/apiSucursal.php';
require_once 'src/apiNormalizacion.php';
require_once 'src/apiTarificacion.php';
require_once 'src/apiRetiro.php';
require_once 'src/apiEtiqueta.php';
require_once 'src/apiManifiesto.php';
require_once 'src/tblServicios.php';
require_once 'src/tblEnvios.php';
require_once 'src/tblTiempos.php';


if (!defined('_PS_VERSION_')) {
    exit;
}

class Correoschile extends CarrierModule
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'correoschile';
        $this->tab = 'shipping_logistics';
        $this->version = '1.0.7';
        $this->author = 'Correos de Chile';
        $this->need_instance = 0;
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Correos de Chile');
        $this->description = $this->l('Ingresa correctamente direcciones desplegando regiones y comunas. Calcula el precio de tus despachos dependiendo del servicio, origen-destino, peso físico y volumétrico. Así podrás informar la tarifa en el momento en el que tu cliente selecciona el tipo de envío (domicilio o sucursales de CorreosChile) en el proceso de venta.');
        //Realiza la admisión de tus paquetes obteniendo el número de seguimiento, etiqueta y manifiesto para un correcto despacho de tus ventas. Realiza retiros programados o agenda un retiro para un día/hora específicos.*
        $this->confirmUninstall = $this->l('¿Confirma que desea desinstalar el modulo?');
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);

    }
    public function install()
    {
        $carrier = $this->addCarrier();
        $this->addZones($carrier);
        $this->addGroups($carrier);
        $this->addRanges($carrier);

        Configuration::updateValue('CORREOSCHILE_NOMBRE_TIENDA', '');
        Configuration::updateValue('CORREOSCHILE_RUT', '');
        Configuration::updateValue('CORREOSCHILE_DIRECCION', '');
        Configuration::updateValue('CORREOSCHILE_COMUNA', '');
        Configuration::updateValue('CORREOSCHILE_CODIGOPOSTAL', '');
        Configuration::updateValue('CORREOSCHILE_NOMBRE', '');
        Configuration::updateValue('CORREOSCHILE_TELEFONO', '');
        Configuration::updateValue('CORREOSCHILE_CODIGOSAP', '');
        Configuration::updateValue('CORREOSCHILE_USUARIO_API', '');
        Configuration::updateValue('CORREOSCHILE_CONTRASENA_API', '');
            
        Configuration::updateValue('CORREOSCHILE_WS_REGION', 'http://b2b.correos.cl/ServicioRegionYComunasExterno/cch/ws/distribucionGeografica/externo/implementacion/ServicioExternoRegionYComunas.asmx');
        Configuration::updateValue('CORREOSCHILE_WS_COMUNA', 'http://b2b.correos.cl/ServicioRegionYComunasExterno/cch/ws/distribucionGeografica/externo/implementacion/ServicioExternoRegionYComunas.asmx');
        Configuration::updateValue('CORREOSCHILE_WS_SUCURSAL', 'http://b2b.correos.cl/ServicioListadoSucursalesExterno/cch/ws/distribucionGeografica/implementacion/ServicioExternoListarSucursales.asmx');
        Configuration::updateValue('CORREOSCHILE_WS_NORMALIZACION', 'http://b2b.correos.cl/ServicioNormalizacionExterno/cch/ws/distribucionGeografica/externo/implementacion/ServicioExternoNormalizacion.asmx');
        Configuration::updateValue('CORREOSCHILE_WS_TARIFICACION', 'http://b2b.correos.cl/ServicioTarificacionCEPEmpresasExterno/cch/ws/tarificacionCEP/externo/implementacion/ExternoTarificacion.asmx');
        Configuration::updateValue('CORREOSCHILE_WS_ETIQUETAS', 'https://restservices.correos.cl/api/ServicioAdmisionCEP/postEtiqueta');
        Configuration::updateValue('CORREOSCHILE_WS_RETIRO', 'http://b2b.correos.cl/ServicioRetiroEnvioExterno/cch/ws/retirosCEP/externo/implementacion/ServicioExternoRetiro.asmx');
        Configuration::updateValue('CORREOSCHILE_WS_ANULACION', 'http://b2b.correos.cl/ServicioAnulacionExterno/cch/ws/enviosCEP/externo/implementacion/ServicioExternoAnulacionEnvio.asmx');

        Configuration::updateValue('CORREOSCHILE_REGIONES', 0);
            
        Configuration::updateValue('CORREOSCHILE_FORMATO_ETIQUETA', 'PDFS');
        Configuration::updateValue('CORREOSCHILE_TARIFICAR', 1);
        Configuration::updateValue('CORREOSCHILE_MARGINAR', 0);
        Configuration::updateValue('CORREOSCHILE_MARGINAR_TIPO', 'VALOR');
        Configuration::updateValue('CORREOSCHILE_MARGEN_VALOR', '');
        Configuration::updateValue('CORREOSCHILE_MARGEN_PORCENTAJE', '');
        Configuration::updateValue('CORREOSCHILE_NORMALIZAR', 0);

        Configuration::updateValue('CORREOSCHILE_TIEMPO_SERVICIOS', 1);
        Configuration::updateValue('CORREOSCHILE_DIAS_EXTRAS','');
        
        
        include(dirname(__FILE__).'/sql/install.php');
        return parent::install() &&
            $this->registerHook('header') &&
            $this->registerHook('displayBeforeBodyClosingTag') &&
            $this->registerHook('actionValidateCustomerAddressForm') &&
            $this->registerHook('displayCarrierExtraContent') &&
            $this->registerHook('actionCarrierProcess') &&
            $this->registerHook('backOfficeHeader') &&
            $this->registerHook('orderConfirmation') &&
            $this->registerHook('actionCarrierUpdate') &&
            $this->installTab('Correos de Chile','controlpanel',0) &&
            $this->installTab('Panel de configuraciones','correos', Tab::getIdFromClassName('controlpanel')) &&
            $this->installTab('Administrar Envíos','envios', Tab::getIdFromClassName('controlpanel')) &&
            $this->installTab('Configuración de Servicios','servicios', Tab::getIdFromClassName('controlpanel')) &&
            $this->crearCarpetas();
    }
    public function uninstall()
    {
        $this->uninstallCarrier();     

        Configuration::deleteByName('CORREOSCHILE_NOMBRE_TIENDA');
        Configuration::deleteByName('CORREOSCHILE_RUT');
        Configuration::deleteByName('CORREOSCHILE_DIRECCION');
        Configuration::deleteByName('CORREOSCHILE_COMUNA');
        Configuration::deleteByName('CORREOSCHILE_CODIGOPOSTAL');
        Configuration::deleteByName('CORREOSCHILE_NOMBRE');
        Configuration::deleteByName('CORREOSCHILE_TELEFONO');
        Configuration::deleteByName('CORREOSCHILE_CODIGOSAP');
            
        Configuration::deleteByName('CORREOSCHILE_USUARIO_API');
        Configuration::deleteByName('CORREOSCHILE_CONTRASENA_API');
            
        Configuration::deleteByName('CORREOSCHILE_WS_REGION');
        Configuration::deleteByName('CORREOSCHILE_WS_COMUNA');
        Configuration::deleteByName('CORREOSCHILE_WS_SUCURSAL');
        Configuration::deleteByName('CORREOSCHILE_WS_NORMALIZACION');
        Configuration::deleteByName('CORREOSCHILE_WS_TARIFICACION');
        Configuration::deleteByName('CORREOSCHILE_WS_ETIQUETAS');
        Configuration::deleteByName('CORREOSCHILE_WS_RETIRO');
        Configuration::deleteByName('CORREOSCHILE_WS_ANULACION');

        Configuration::deleteByName('CORREOSCHILE_REGIONES');
            
        Configuration::deleteByName('CORREOSCHILE_FORMATO_ETIQUETA');
        Configuration::deleteByName('CORREOSCHILE_TARIFICAR');
        Configuration::deleteByName('CORREOSCHILE_MARGINAR');
        Configuration::deleteByName('CORREOSCHILE_MARGINAR_TIPO');
        Configuration::deleteByName('CORREOSCHILE_MARGEN_VALOR');
        Configuration::deleteByName('CORREOSCHILE_MARGEN_PORCENTAJE');
        Configuration::deleteByName('CORREOSCHILE_NORMALIZAR');

        Configuration::deleteByName('CORREOSCHILE_CARRIER_ID');

        Configuration::deleteByName('CORREOSCHILE_TIEMPO_SERVICIOS');
        Configuration::deleteByName('CORREOSCHILE_DIAS_EXTRAS');

        
        include(dirname(__FILE__).'/sql/uninstall.php');
        return parent::uninstall() &&
            $this->unregisterHook('header') &&
            $this->unregisterHook('displayBeforeBodyClosingTag') &&
            $this->unregisterHook('actionValidateCustomerAddressForm') &&
            $this->unregisterHook('displayCarrierExtraContent') &&
            $this->unregisterHook('actionCarrierProcess') &&            
            $this->unregisterHook('backOfficeHeader') &&
            $this->unregisterHook('orderConfirmation') &&
            $this->unregisterHook('actionCarrierUpdate') &&
            $this->uninstallTab('envios') &&
            $this->uninstallTab('servicios') &&
            $this->uninstallTab('correos') &&
            $this->uninstallTab('controlpanel');
    }

    //Instalación carpetas necesarias en Upload (Prestashop)
    public function crearCarpetas()
    {
        if (!file_exists(_PS_UPLOAD_DIR_.'/correoschile')) {
            @mkdir(_PS_UPLOAD_DIR_.'/correoschile', 0775, true);
            //@chmod(_PS_UPLOAD_DIR_.'/correoschile', 0775);
        }
        if (!file_exists(_PS_UPLOAD_DIR_.'/correoschile/etiquetas/') && file_exists(_PS_UPLOAD_DIR_.'/correoschile')) {
            @mkdir(_PS_UPLOAD_DIR_.'/correoschile/etiquetas/', 0775, true);
            //@chmod(_PS_UPLOAD_DIR_.'/correoschile/etiquetas/', 0775);
        }
        if (!file_exists(_PS_UPLOAD_DIR_.'/correoschile/manifiestos/') && file_exists(_PS_UPLOAD_DIR_.'/correoschile')) {
            @mkdir(_PS_UPLOAD_DIR_.'/correoschile/manifiestos/', 0775, true);
            //@chmod(_PS_UPLOAD_DIR_.'/correoschile/manifiestos/', 0775);
        }

        return true;
    }
    //Instalación de tabs correoschile en panel de administración
    public function installTab($titulo, $nombreClase, $parent)
    {
        $tab = new Tab();
        $tab->active = 1;
        foreach (Language::getLanguages() as $lang) {
            $tab->name[$lang['id_lang']] = $this->l($titulo);
        }
        $tab->class_name = $nombreClase;
        $tab->module = $this->name;
        $tab->id_parent = $parent;
        return $tab->add();
    }
    //Desinstalacion de tabs correoschile en panel de administración
    public function uninstallTab($correostab)
    {
        $id_tab = Tab::getIdFromClassName($correostab);
        if($id_tab){
            $tab = new Tab($id_tab);
            return $tab->delete();
        }
        return true;
    }
    //Desinstalar carro existente, cambia el carro predeterminado si se requiere
    public function uninstallCarrier()
    {
        $carrierId = new Carrier((int)(Configuration::get('CORREOSCHILE_CARRIER_ID')));
        if(Configuration::get('PS_CARRIER_DEFAULT') == (int)($carrierId->id)){
            $carriers = Carrier::getCarriers($cookie->id_lang, true, false, false, NULL, PS_CARRIERS_AND_CARRIER_MODULES_NNED_RANGE);
            foreach($carriers as $carrier)
            {
                if($carrier['active'] && !$carrier['deleted'] && ($carrier['name'] !== $this->name)){
                    Configuration::updateValue('PS_CARRIER_DEFAULT', $carrier['id_carrier']);
                }
            }
        }
        if(!$carrierId->delete()){
            return false;
        }
        
    }
    protected function addCarrier()
    {
        $carrier = new Carrier();
        $carrier->name = $this->l('Correos de Chile');
        $carrier->is_module = true;
        $carrier->active = 1;
        $carrier->range_behavior = 1;
        $carrier->need_range = 1;
        $carrier->shipping_external = true;
        $carrier->range_behavior = 0;
        $carrier->external_module_name = $this->name;
        $carrier->shipping_method = 2;

        foreach (Language::getLanguages() as $lang)
            $carrier->delay[$lang['id_lang']] = $this->l('Envíos Nacionales');

        if ($carrier->add() == true)
        {
            @copy(dirname(__FILE__).'/views/img/carrier_image.jpg', _PS_SHIP_IMG_DIR_.'/'.(int)$carrier->id.'.jpg');
            Configuration::updateValue('CORREOSCHILE_CARRIER_ID', (int)$carrier->id);
            return $carrier;
        }

        return false;
    }
    protected function addGroups($carrier)
    {
        $groups_ids = array();
        $groups = Group::getGroups(Context::getContext()->language->id);
        foreach ($groups as $group)
            $groups_ids[] = $group['id_group'];

        $carrier->setGroups($groups_ids);
    }
    protected function addRanges($carrier)
    {
        $range_price = new RangePrice();
        $range_price->id_carrier = $carrier->id;
        $range_price->delimiter1 = '0';
        $range_price->delimiter2 = '10000';
        $range_price->add();

        $range_weight = new RangeWeight();
        $range_weight->id_carrier = $carrier->id;
        $range_weight->delimiter1 = '0';
        $range_weight->delimiter2 = '10000';
        $range_weight->add();
    }
    protected function addZones($carrier)
    {
        $zones = Zone::getZones();

        foreach ($zones as $zone)
            $carrier->addZone($zone['id_zone']);
    }
    //Preparación del contenido del Formulario de configuración
    public function getContent()
    {
        if (((bool)Tools::isSubmit('submitCorreoschileModule')) == true) {
            $this->postProcess();
        }
        $this->context->smarty->assign('module_dir', $this->_path);
        $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');
        return $output.$this->renderForm();
    }
    //Despliegue del Formulario de configuración
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitCorreoschileModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        $forms = array($this->getInformacionTiendaForm(),
                       $this->getCredencialServiciosWebForm(),
                       $this->getURLServiciosWebForm(),
                       $this->getURLConfiguracionAdicionalForm(),
                       $this->getConfiguracionTransportistaForm());
        return $helper->generateForm($forms);
    }
    //Formulario de configuración, sección Información de la tienda.
    protected function getInformacionTiendaForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Información de la Tienda'),
                    'icon' => 'icon-info-circle',
                ),
                'input' => array(
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_NOMBRE_TIENDA',
                        'label' => $this->l('Nombre Remitente (Tienda)'),
                        'required' => true
                    ),
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_RUT',
                        'label' => $this->l('Rut'),
                        'required' => true
                    ),                    
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_DIRECCION',
                        'label' => $this->l('Dirección'),
                        'required' => true
                    ),                    
                    array(
                        'type' => 'select',
                        'name' => 'CORREOSCHILE_COMUNA',
                        'label' => $this->l('Comuna'),
                        'options' => array(
                            'query' => ApiComuna::jsonComunas(),
                            'id' => 'Comuna',
                            'name' => 'Comuna'
                        ),
                        'required' => true
                    ),                    
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_CODIGOPOSTAL',
                        'label' => $this->l('Código Postal'),
                        'required' => true
                    ),                                        
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_NOMBRE',
                        'label' => $this->l('Nombre'),
                        'required' => true
                    ),                                                            
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_TELEFONO',
                        'label' => $this->l('Teléfono'),
                        'required' => true
                    ),                      
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_CODIGOSAP',
                        'label' => $this->l('Código Cliente (SAP)'),
                        'size' => 6,
                        'required' => true
                    ), 
                ),
                'submit' => array(
                    'title' => $this->l('Guardar'),
                ),
            ),
        );
    }
    //Formulario de configutación, sección Credencial Servicios Web
    protected function getCredencialServiciosWebForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Credencial Servicios Web'),
                    'icon' => 'icon-user',
                ),
                'input' => array(
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_USUARIO_API',
                        'label' => $this->l('Usuario'),
                        'size' => 50,
                        'required' => true
                    ),
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_CONTRASENA_API',
                        'label' => $this->l('Contraseña'),
                        'size' => 50,
                        'required' => true
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Guardar'),
                ),
            ),
        );
    }
    //Formulario de configuración, sección URL servicios Web
    protected function getURLServiciosWebForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('URL Servicios Web'),
                    'icon' => 'icon-link',
                ),
                'input' => array(
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_WS_REGION',
                        'label' => $this->l('Regiones'),
                        'required' => true,
                        'desc' => $this->l('Este servicio se utiliza para completar el combo de regiones.'),
                    ),
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_WS_COMUNA',
                        'label' => $this->l('Comunas'),
                        'required' => true,
                        'desc' => $this->l('Este servicio se utiliza para completar el combo de comunas.'),
                    ),
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_WS_SUCURSAL',
                        'label' => $this->l('Sucursales'),
                        'required' => true,
                        'desc' => $this->l('Este servicio se utiliza para completar el combo de sucursales.'),
                    ),
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_WS_NORMALIZACION',
                        'label' => $this->l('Normalización'),
                        'required' => true,
                        'desc' => $this->l('Este servicio se utiliza para comprobar las direcciones y obtener el código postal.'),
                    ),
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_WS_TARIFICACION',
                        'label' => $this->l('Tarificación'),
                        'required' => true,
                        'desc' => $this->l('Este servicio se utiliza para calcular el costo de los envíos en base a la comuna de destino, peso y volumen de los productos.'),
                    ),
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_WS_ETIQUETAS',
                        'label' => $this->l('Etiquetas'),
                        'required' => true,
                        'desc' => $this->l('Este servicio se utiliza para generar las etiquetas de sus pedidos.'),
                    ),
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_WS_RETIRO',
                        'label' => $this->l('Retiro'),
                        'required' => true,
                        'desc' => $this->l('Este servicio se utiliza para agendar el retiro de sus pedidos en su tienda.'),
                    ),
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_WS_ANULACION',
                        'label' => $this->l('Anulación'),
                        'required' => true,
                        'desc' => $this->l('Este servicio se utiliza para anular las etiquetas generadas de los pedidos.'),
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Guardar'),
                ),
            ),
        );
    }
    //Formulario de configuración, sección configuración adicional
    protected function getURLConfiguracionAdicionalForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Configuración Adicional'),
                    'icon' => 'icon-cog',
                ),
                'input' => array(
                    array(
                        'type' => 'select',
                        'name' => 'CORREOSCHILE_FORMATO_ETIQUETA',
                        'label' => $this->l('Formato Etiqueta'),
                        'desc' => $this->l('Formato en que será generada la etiqueta para los envíos. El formato PDF admite hasta 30 caractéres en dirección de origen y destino, PDFs admite 60 caractéres'),
                        'options' => array(
                            'query' => array(
                            array(
                                'id_option' => 'PDF',
                                'name' => 'PDF'
                            ),
                            array(
                                'id_option' => 'PDFS',
                                'name' => 'PDF Small'
                            ),
                            array(
                                'id_option' => 'ZPL',
                                'name' => 'Impresora Zebra'
                            ),),
                            'id' => 'id_option',
                            'name' => 'name'
                        ),
                        'required' => true
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Mostrar regiones'),
                        'name' => 'CORREOSCHILE_REGIONES',
                        'is_bool' => true,
                        'desc' => $this->l('Al activar esta opción se añadirá al formulario de facturación el campo para selección de regiones y así poder filtrar las comunas en base a la región seleccionada. 
                        Esta funcionalidad es propia del módulo de Correos de Chile y podría interferir con otro módulo que realice una funcionalidad similar. Se efectuarán los cambios cada vez que las configuraciones
                        de este panel sean guardadas. Las modificaciones que se aplican al activar esta opción se pueden realizar completamente de forma manual, para esto ver Internacional -> Ubicaciones Geográficas -> Zonas/Países.'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Tarificar los envíos'),
                        'name' => 'CORREOSCHILE_TARIFICAR',
                        'is_bool' => true,
                        'desc' => $this->l('Indica si se sumará el costo de envío en el total del cliente o desea asumir el costo de envío y para el cliente sea gratuito.'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Marginar envíos'),
                        'name' => 'CORREOSCHILE_MARGINAR',
                        'is_bool' => true,
                        'desc' => $this->l('Indica si agregará un valor adicional al costo total del envío'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type' => 'select',
                        'name' => 'CORREOSCHILE_MARGINAR_TIPO',
                        'label' => $this->l('Tipo de margen'),
                        'desc' => $this->l('Indica el tipo de margen que desea aplicar'),
                        'options' => array(
                            'query' => array(
                                array(
                                    'id_option' => 'VALOR',
                                    'name' => 'VALOR ($)'
                                ),
                                array(
                                    'id_option' => 'PORCENTAJE',
                                    'name' => 'PORCENTAJE (%)'
                                ),
                            ),
                            'id' => 'id_option',
                            'name' => 'name'
                        ),
                        'required' => true
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('Marginar envíos ($)'),
                        'name' => 'CORREOSCHILE_MARGEN_VALOR',
                        'required' => false,
                        'desc' => $this->l('Indica el valor en PESOS que desea agregar al costo total de los envíos, SOLO NUMEROS'),
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('Marginar envíos (%)'),
                        'name' => 'CORREOSCHILE_MARGEN_PORCENTAJE',
                        'required' => false,
                        'desc' => $this->l('Indica el valor PORCENTUAL que desea agregar al costo total de los envíos, SOLO NUMEROS'),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Tiempo de servicios'),
                        'name' => 'CORREOSCHILE_TIEMPO_SERVICIOS',
                        'is_bool' => true,
                        'desc' => $this->l('Indica si desea mostrar el tiempo de los servicios de Correos de Chile hacia los clientes'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type' => 'text',
                        'name' => 'CORREOSCHILE_DIAS_EXTRAS',
                        'label' => $this->l('Días adicionales'),
                        'desc' => $this->l('Agregar días adicionales a los servicios, SOLO NUMEROS')
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Validar dirección'),
                        'name' => 'CORREOSCHILE_NORMALIZAR',
                        'is_bool' => true,
                        'desc' => $this->l('Utilice esta opción si desea que Correos de Chile valide las direcciones ingresadas por los clientes utilizando el servicio de normalización, de lo contrario deberá validar manualmente la dirección de la orden para evitar errores con la generación de etiquetas'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),  
                ),
                'submit' => array(
                    'title' => $this->l('Guardar'),
                ),
            ),
        );
    }
    protected function getConfiguracionTransportistaForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Configuración transportista'),
                    'icon' => 'icon-cog',
                ),
                'input' => array(
                    array(
                        'type' => 'text',
                        'label' => $this->l('ID Transportista'),
                        'name' => 'CORREOSCHILE_CARRIER_ID',
                        'required' => false,
                        'desc' => $this->l('Indica el identificador del transportista creado con la instalación del módulo, este solo debe ser modificado en caso de que el identificador del transportista cambie. Este ID se puede revisar en Transporte -> Transportistas. Cambiar este campo sin requerirlo generará problemas en el módulo, 
                        SOLO MODIFICAR EN EL CASO INDICADO'),
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Guardar'),
                ),
            ),
        );
    }
    protected function getConfigFormValues()
    {
        return array(
            'CORREOSCHILE_NOMBRE_TIENDA' => Configuration::get('CORREOSCHILE_NOMBRE_TIENDA'),
            'CORREOSCHILE_RUT' => Configuration::get('CORREOSCHILE_RUT'),
            'CORREOSCHILE_DIRECCION' => Configuration::get('CORREOSCHILE_DIRECCION'),
            'CORREOSCHILE_COMUNA' => Configuration::get('CORREOSCHILE_COMUNA'),
            'CORREOSCHILE_CODIGOPOSTAL' => Configuration::get('CORREOSCHILE_CODIGOPOSTAL'),
            'CORREOSCHILE_NOMBRE' => Configuration::get('CORREOSCHILE_NOMBRE'),
            'CORREOSCHILE_TELEFONO' => Configuration::get('CORREOSCHILE_TELEFONO'),
            'CORREOSCHILE_CODIGOSAP' => Configuration::get('CORREOSCHILE_CODIGOSAP'),
            
            'CORREOSCHILE_USUARIO_API' => Configuration::get('CORREOSCHILE_USUARIO_API'),
            'CORREOSCHILE_CONTRASENA_API' => Configuration::get('CORREOSCHILE_CONTRASENA_API'),
            
            'CORREOSCHILE_WS_REGION' => Configuration::get('CORREOSCHILE_WS_REGION'),
            'CORREOSCHILE_WS_COMUNA' => Configuration::get('CORREOSCHILE_WS_COMUNA'),
            'CORREOSCHILE_WS_SUCURSAL' => Configuration::get('CORREOSCHILE_WS_SUCURSAL'),
            'CORREOSCHILE_WS_NORMALIZACION' => Configuration::get('CORREOSCHILE_WS_NORMALIZACION'),
            'CORREOSCHILE_WS_TARIFICACION' => Configuration::get('CORREOSCHILE_WS_TARIFICACION'),
            'CORREOSCHILE_WS_ETIQUETAS' => Configuration::get('CORREOSCHILE_WS_ETIQUETAS'),
            'CORREOSCHILE_WS_RETIRO' => Configuration::get('CORREOSCHILE_WS_RETIRO'),
            'CORREOSCHILE_WS_ANULACION' => Configuration::get('CORREOSCHILE_WS_ANULACION'),

            'CORREOSCHILE_REGIONES' => Configuration::get('CORREOSCHILE_REGIONES'),
            
            'CORREOSCHILE_FORMATO_ETIQUETA' => Configuration::get('CORREOSCHILE_FORMATO_ETIQUETA'),
            'CORREOSCHILE_TARIFICAR' => Configuration::get('CORREOSCHILE_TARIFICAR'),
            'CORREOSCHILE_MARGINAR' => Configuration::get('CORREOSCHILE_MARGINAR'),
            'CORREOSCHILE_MARGINAR_TIPO' => Configuration::get('CORREOSCHILE_MARGINAR_TIPO'),
            'CORREOSCHILE_MARGEN_VALOR' => Configuration::get('CORREOSCHILE_MARGEN_VALOR'),
            'CORREOSCHILE_MARGEN_PORCENTAJE' => Configuration::get('CORREOSCHILE_MARGEN_PORCENTAJE'),
            'CORREOSCHILE_NORMALIZAR' => Configuration::get('CORREOSCHILE_NORMALIZAR'),

            'CORREOSCHILE_TIEMPO_SERVICIOS' => Configuration::get('CORREOSCHILE_TIEMPO_SERVICIOS'),
            'CORREOSCHILE_DIAS_EXTRAS' => Configuration::get('CORREOSCHILE_DIAS_EXTRAS'),

            'CORREOSCHILE_CARRIER_ID' => Configuration::get('CORREOSCHILE_CARRIER_ID'),
        );
    }
    //Al presionar botón guardar en panel de configuraciones
    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();
        foreach (array_keys($form_values) as $key) 
        {
            Configuration::updateValue($key, Tools::getValue($key));
        }

        $query = "SELECT format FROM "._DB_PREFIX_."address_format WHERE id_country=68";    
        $result = Db::getInstance()->ExecuteS($query);
        /**Opción mostrar regiones inactivo */
        if(Configuration::get('CORREOSCHILE_REGIONES')==false){   
            $sql = 'UPDATE '._DB_PREFIX_.'state SET active="0" WHERE id_country="68" AND iso_code 
            IN ("202","203","204","205","206","207","208","209","210","211","212","213","214","646","659","8783")';
            Db::getInstance()->Execute($sql);
            Db::getInstance()->update('country', array('contains_states'=> '0'),'id_country = 68');
            /**Valída State:name en formato actual de formulario*/
            if(preg_match("/State:name/i", $result[0]['format'])){
                Db::getInstance()->update('address_format', array('format'=> preg_replace("/State:name/i", "", $result[0]['format'])),'id_country = 68');
            }
        }
        /**Opción mostrar regiones activo */
        if(Configuration::get('CORREOSCHILE_REGIONES')==true){
            $sql = 'UPDATE '._DB_PREFIX_.'state SET active="1" WHERE id_country="68" AND iso_code 
            IN ("202","203","204","205","206","207","208","209","210","211","212","213","214","646","659","8783")';
            Db::getInstance()->Execute($sql);
            Db::getInstance()->update('country', array('contains_states'=> '1'),'id_country = 68');
            /**Valída State:name en formato actual de formulario*/
            if(!preg_match("/State:name/i", $result[0]['format'])){
                Db::getInstance()->update('address_format', array('format'=> $result[0]['format'].' '."State:name"),'id_country = 68');
            }
        }
    } 
    //Se realiza el calculo de costo de envío del servicio seleccionado.
    public function getOrderShippingCost($params, $shipping_cost)
    {           
        $carrier = new Carrier(Context::getContext()->cart->id_carrier);
        
        if($this->context->cookie->__isset('correoschile_servicio') === false){
            $servicioPredeterminado = tblServicios::servicioPredeterminado(); 
            $this->context->cookie->__set('correoschile_servicio', $servicioPredeterminado['0']['codigoServicio']);
            $this->context->cookie->write();
        }
        $servicio = $this->context->cookie->correoschile_servicio;
        if(Configuration::get('CORREOSCHILE_TARIFICAR') == true)
        {
            $servicioActivo = tblServicios::estadoServicio($servicio);
            if($servicioActivo['estaDisponible'] == false){
                $servicioPredeterminado = tblServicios::servicioPredeterminado();
                $servicio = $servicioPredeterminado['0']['codigoServicio'];
                $this->context->cookie->__set('correoschile_servicio', $servicio);
                $this->context->cookie->write();
            }
            if (Context::getContext()->customer->logged == true)
            {

                try {

                    $id_address_delivery    = Context::getContext()->cart->id_address_delivery;
                    $address                = new Address($id_address_delivery);
                    $codigoServicio         = $servicio;
                    $comunaRemitente        = trim(Configuration::get('CORREOSCHILE_COMUNA'));
                    $comunaDestinatario     = $address->city;
                    
                    $kilos = Context::getContext()->cart->getTotalWeight();
                    $volumen = 0;
                    $ok = true;


                    $serviciosSucursales = tblServicios::serviciosSucursalPredeterminado();
                    if(!empty($serviciosSucursales) && !empty($comunaDestinatario)){
                        $serviciosDisponibles = tblServicios::serviciosActivos();
                        $servicioValido = $this->validarSucursales($comunaDestinatario);
                        if($servicioValido == false){
                            foreach($serviciosDisponibles as $servicio){
                                if($servicio['esSucursal'] == false){
                                    $codigoServicio = array('codigoServicio' => $servicio['codigoServicio']);
                                    $codigoServicio = $codigoServicio['codigoServicio'];
                                    $this->context->cookie->__set('correoschile_servicio', $codigoServicio);
                                    $this->context->cookie->write();
                                    break;
                                }else{
                                    return false;
                                }
                            }
                        }
                    }
                                        
                    foreach($this->context->cart->getProducts() as $producto)
                    {
                        if(round($producto['width'],3) == 0 || round($producto['height'],3) == 0 || round($producto['depth'],3) == 0){
                            $ok = false;
                            break;
                        }
                        $volumen += ((round($producto['width'],3) * round($producto['height'],3) * round($producto['depth'],3)/1000000)* $producto['quantity']);
                    }
                    if($ok === false){
                        $this->errorLogCorreosChile('CorreosChile::CalculateShipping- Falló al calcular tarifa - Error : Producto sin dimensiones en carro', 3, 'Cart - Tarificador', (int) $address->id_customer);
                        return false;
                    }

                    $volumen = round(number_format($volumen,7),3);
                    $kilos = round(number_format($kilos,7),3);

                    if($volumen == 0){
                        $volumen = 0.001;
                    }
                    if($kilos == 0){
                        $kilos = 0.001;
                    }

                    $shipping_cost = ApiTarificacion::totalConsultaCoberturaPorProducto($codigoServicio, $comunaRemitente, $comunaDestinatario, $kilos, $volumen);  

                    if($shipping_cost == 0){
                        return false;
                    }

                    $shipping_cost = $this->aplicarMargenSobreCostoDeEnvio($shipping_cost);

                } catch(Exception $e) {
                    $this->errorLogCorreosChile('CorreosChile::CalculateShipping- Falló al calcular tarifa - '.$e->getMessage(), 3, 'Cart - Tarificador', (int) $address->id_customer);
                    return $e;
                }
            }
        } else {
            $shipping_cost = 0;
        }
        return $shipping_cost;        
    }
    //Validar comuna para comunaDestinatario
    public function validarComunaIngresada($comunaDestinatario)
    {
        $jsonComunas = apiComuna::jsonComunas();
        foreach($jsonComunas as $comunas){
            if($comunaDestinatario == $comunas->Comuna){
                $idComuna = $comunas->idComuna;
                return $idComuna;
            }
        }
        return false;
    }
    //Validar sucursales para comunaDestinatario
    public function validarSucursales($comunaDestinatario){

        $serviciosDisponibles   = tblServicios::serviciosActivos();
        $servicioPredeterminado = tblServicios::servicioPredeterminado();
        $codigoPredeterminado   = $servicioPredeterminado[0]['codigoServicio'];
        $esSucursal             = $servicioPredeterminado[0]['esSucursal'];

        if($esSucursal == true){
            $idComuna = $this->validarComunaIngresada($comunaDestinatario);
            if(!is_bool($idComuna)){
                $sucursales = json_decode(json_encode(ApiSucursal::listarSucursalesSegunComuna($idComuna)), true);
                if(is_array($sucursales) && array_key_exists('DescripcionOficina', $sucursales[0])){
                    return true;
                }
            }
            return false;
        }
        return false;
    }
    public function getOrderShippingCostExternal($params)
    {
        
    }
    //Aplicar margen sobre el costo de envio.
    public function aplicarMargenSobreCostoDeEnvio($costoEnvio)
    {
        if(Configuration::get('CORREOSCHILE_MARGINAR') == true){
            if (Configuration::get('CORREOSCHILE_MARGINAR_TIPO') == 'VALOR'){
                $costoEnvio = $costoEnvio + Configuration::get('CORREOSCHILE_MARGEN_VALOR');
            }elseif(Configuration::get('CORREOSCHILE_MARGINAR_TIPO') == 'PORCENTAJE'){
                $auxCostoEnvio = $costoEnvio * Configuration::get('CORREOSCHILE_MARGEN_PORCENTAJE')/100;
                $costoEnvio = $costoEnvio + $auxCostoEnvio;
            }
            if($costoEnvio < 0){
                $costoEnvio = 0;
            }
        }
        return $costoEnvio;
    }    
    //Agregar archivos CSS y JavaScript necesarios en el sitio.
    public function hookHeader()
    {
        $this->context->controller->addCSS($this->_path.'views/css/front.css');
        $this->context->controller->addJS($this->_path.'views/js/front.js');
    }
    //Se agrega activación del AddressHelper y ExtraCarrierContent al final de body.
    public function hookDisplayBeforeBodyClosingTag(){
        $jsonRegiones = json_encode(ApiRegion::listarRegionesChile());
        $jsonComunas = json_encode(ApiComuna::jsonComunas());
        $urlComuna = Context::getContext()->link->getModuleLink('correoschile', 'comuna', array('ajax'=>true));
        $urlNormalizacion = Context::getContext()->link->getModuleLink('correoschile', 'normalizacion', array('ajax'=>true));
        $urlServicio = Context::getContext()->link->getModuleLink('correoschile', 'normalizacion', array('ajax'=>true));
        return "<script>"
        . "var correoschile_regiones = $jsonRegiones;"
        . "var correoschile_comunas = $jsonComunas;"
        . "$(document).ready(function(){ "
        . "new Correoschile_AddressHelper({ 'urlComunas' : '$urlComuna', 'urlNormalizacion': '$urlNormalizacion' });"
        . "new Correoschile_ExtraCarrierContent({ 'urlServicio' : '$urlServicio' });"
        . " });</script>";
    }
    //Se realiza una validación de la dirección contra el servicio de normalización.
    public function hookActionValidateCustomerAddressForm($params)
    {
        if(Configuration::get('CORREOSCHILE_NORMALIZAR') == false){
            return false;
        }
        $form = $params['form'];
        $comuna = $form->getField("city") ? $form->getField("city")->getValue() : '';
        $direccion = $form->getField("address1") ? $form->getField("address1")->getValue() : '';
        $codigoPostal = $form->getField("postcode") ? $form->getField("postcode")->getValue() : '';
        $codigoPostal = str_replace('-','',$codigoPostal);

        $isValid = true;
        try {
            $direccionNormalizada = ApiNormalizacion::normalizarDireccion($direccion, $comuna);
            if($codigoPostal !== '' && $codigoPostal !== $direccionNormalizada->CodigoPostal){
                $form->getField('postcode')->addError('Código postal/Zip diferente, debería ser: ' . $direccionNormalizada->CodigoPostal);
                $isValid = false;
            }
        } catch (Exception $e) {
            $form->getField('address1')->addError("La dirección no es válida, no ha superado el proceso de normalización.");
            $isValid = false;
        }
        return $isValid;
    }
    //Se agrega contenido adicional en el método de envío.
    public function hookDisplayCarrierExtraContent()
    {      
        //$this->context->cookie->__unset('correoschile_sucursal');
        $this->context->cookie->__unset('kilos');
        $this->context->cookie->__unset('volumen');
        $html = '';
        $html .= '<div class="row px-2">';
        
        try
        {
            $id_address_delivery    = Context::getContext()->cart->id_address_delivery;
            $address                = new Address($id_address_delivery);
            $comunaRemitente        = trim(Configuration::get('CORREOSCHILE_COMUNA'));
            $comunaDestinatario     = $address->city;
            $direccionDestinatario  = $address->address1;

            $kilos                  = Context::getContext()->cart->getTotalWeight();
            $volumen = 0;

            foreach($this->context->cart->getProducts() as $producto)
            {
                if(round($producto['width'],3) == 0 || round($producto['height'],3) == 0 || round($producto['depth'],3) == 0){
                    $volumen = 0;
                    break;
                }
                $volumen += ((round($producto['width'],3) * round($producto['height'],3) * round($producto['depth'],3)/1000000)* $producto['quantity']);
            }
            
            $volumen = round(number_format($volumen,7),3);
            $kilos = round(number_format($kilos,7),3);
            
            if($volumen == 0){
                $volumen = 0.001;
            }
            if($kilos == 0){
                $kilos = 0.001;
            }
            
            $servicioSeleccionado   = $this->context->cookie->correoschile_servicio;
            $sucursalSeleccionada   = $this->context->cookie->correoschile_sucursal;
            $servicioPredeterminado = tblServicios::servicioPredeterminado();
            $servicios              = tblServicios::serviciosActivos();
            $comuna                 = ApiComuna::obtenerComunaPorNombre($comunaDestinatario);

            $cobertura = ApiTarificacion::consultaCobertura($comunaRemitente, $comunaDestinatario, $kilos, $volumen);
            if(Configuration::get('CORREOSCHILE_TARIFICAR') == true){
                foreach($cobertura as $value)
                {
                    $array[$value->CodigoServicio] = $this->aplicarMargenSobreCostoDeEnvio($value->TotalTasacion->Total);
                }
            }else{
                foreach($cobertura as $value)
                {
                    $array[$value->CodigoServicio] = 0;
                }
            }
            
            foreach($servicios as $servicio)
            {
				if(is_array($array)){
					if(array_key_exists($servicio['codigoServicio'], $array)){
                        $total = 'total'.$servicio['abreviacion'];
						if($servicio['esSucursal'] == true){
							if(is_null($comuna) === false){
                                $sucursales = json_decode(json_encode(ApiSucursal::listarSucursalesSegunComuna($comuna->Iata)), true);
								if(is_array($sucursales) && array_key_exists('DescripcionOficina', $sucursales[0])){
                                    $$total = $array[$servicio['codigoServicio']];
								}else{
                                    $$total = 0;
                                }
							}else{
								$$total = 0;
							}
						}else{
							$$total = $array[$servicio['codigoServicio']];
						}
                        $totales[$servicio['abreviacion']] = $$total;
					}
                }
            }
        
            $tipoServicio = tblServicios::tipoServicio($this->context->cookie->__get('correoschile_servicio'));
            
            if(empty($sucursalSeleccionada)){
                $sucursalSeleccionada = $sucursales[0]['DescripcionOficina'];
            }

            $html .= '<div class="col"></div>';
            $html .= '<div class="row" style="margin-bottom:16px;">';
            $html .= '<div class="col px-2">';
            $html .= '<div class="help-block">';
            $html .= '<table class="services_correos" style="width: 100%; font-size: 14px;" ><tr>';
            if($tipoServicio['esSucursal'] == true){
                $html .= '<td><b>Servicio:</b></td>';
                $html .= '<td>'.$tipoServicio['descripcion'].' ('.$sucursalSeleccionada.') </td>';
            }else{
                $html .= '<td><b>Servicio:</b></td>';
                $html .= '<td>'.$tipoServicio['descripcion'].'</td>';
            }
            $html .= '<td style="text-align: right;"><a id="correoschile_extracontent_link" data-toggle="collapse" href="#correoschile_extracontent" role="button" style="font-size: 14px;"> Cambiar <i class="material-icons">&#xE5CF;</i></a></td>';       
            $html .= '</tr></table>';      
            $html .= '</div>';
            $html .= '<div class="collapse" id="correoschile_extracontent">';
            $html .= '<div class="form-group row ">';
            $html .= '<label class="col-md-1 form-control-label"></label>';
            $html .= '<div class="col-md-10 form-control-valign">';

            foreach($servicios as $servicio)
            {
                if(array_key_exists($servicio['codigoServicio'], $array)){

                    $tiempoServicio = tblTiempos::buscaTiempo($servicio['codigoServicio'], $comunaRemitente, $comunaDestinatario);
                    $tiempoPredeterminado = tblServicios::buscaTiempoPredeterminado($servicio['codigoServicio']);
                    $total_ = $totales[$servicio['abreviacion']];
                    $tiempoFinal = '';

                    if(Configuration::get('CORREOSCHILE_TIEMPO_SERVICIOS') == true){
                        if(Configuration::get('CORREOSCHILE_DIAS_EXTRAS') !=='' && !empty(Configuration::get('CORREOSCHILE_DIAS_EXTRAS')) && Configuration::get('CORREOSCHILE_DIAS_EXTRAS') !== 0 ){
                            if(!empty($tiempoServicio)){
                                $arrayTiempo = explode(' ',$tiempoServicio[0]['tiempo']);
                                if(count($arrayTiempo) > 2){
                                    $desde = (int)$arrayTiempo[0] + (int)Configuration::get('CORREOSCHILE_DIAS_EXTRAS');
                                    $hasta = (int)$arrayTiempo[2] + (int)Configuration::get('CORREOSCHILE_DIAS_EXTRAS');
                                    $tiempoFinal = '('.$desde.' a '.$hasta.' días)';
                                }else{
                                    $desde = (int)$arrayTiempo[0] + (int)Configuration::get('CORREOSCHILE_DIAS_EXTRAS');
                                    $tiempoFinal = '('.$desde.' días)';
                                }
                            }else{
                                $arrayTiempo = explode(' ',$tiempoPredeterminado[0]['tiempoPredeterminado']);
                                if(count($arrayTiempo) > 2){
                                    $desde = (int)$arrayTiempo[0] + (int)Configuration::get('CORREOSCHILE_DIAS_EXTRAS');
                                    $hasta = (int)$arrayTiempo[2] + (int)Configuration::get('CORREOSCHILE_DIAS_EXTRAS');
                                    $tiempoFinal = '('.$desde.' a '.$hasta.' días)';
                                }else{
                                    $desde = (int)$arrayTiempo[0] + (int)Configuration::get('CORREOSCHILE_DIAS_EXTRAS');
                                    $tiempoFinal = '('.$desde.' días)';
                                }
                            }
                        }else{
                            $tiempoFinal = '('.$tiempoPredeterminado[0]['tiempoPredeterminado'].')';
                        }
                    }

                    $html .= '<label class="radio-inline"><span class="custom-radio">';
                    $html .= '<input ' . ($total_ === 0 ? 'disabled="disabled"' : '') . ' id="correoschile_servicio_'.$servicio['codigoServicio'].'" name="correoschile_servicio" type="radio" value="'.$servicio['codigoServicio'].'" ' . ($servicioSeleccionado === $servicio['codigoServicio'] && $total_ > 0 ? 'checked' : '') . '>';
                    $html .= '<span></span></span> '.$servicio['descripcion'] .' '. ($total_ === 0 ? '(No disponible)' : ' ('.Tools::displayPrice($total_).') ') .($total_ === 0 ? '' : $tiempoFinal).'</label>';
                    $html .= '<br>';
                    
                    if($servicio['esSucursal'] == true && $total_ > 0){
                        if(is_array($sucursales) && array_key_exists('DescripcionOficina', $sucursales[0])){
                            $html .= '<div id="coreoschile_sucursales_'.$servicio['codigoServicio'].'" class="form-group row" ' . ($servicioSeleccionado === '24' ? 'style="display:none;"' : '') . '>';
                            $html .= '<label class="col-md-1 form-control-label"></label>';
                            $html .= '<div class="col-md-10 form-control-valign">';
                            $html .= '<select class="form-control form-control-select" id="correoschile_sucursal_'.$servicio['codigoServicio'].'" name="correoschile_sucursal_'.$servicio['codigoServicio'].'">';
                            if(is_array($sucursales)) {
                                foreach ($sucursales as $sucursal) {
                                    $html .= '<option value="' . $sucursal['DescripcionOficina'] . '" ' . ($sucursalSeleccionada === $sucursal['DescripcionOficina'] ? "selected" : "") . '>' . $sucursal['DescripcionOficina'] . '</option>';
                                }
                            } else {
                                if(property_exists($sucursales, 'DescripcionOficina')) {
                                    $html .= '<option value="' . $sucursal['DescripcionOficina'] . '" ' . ($sucursalSeleccionada === $sucursal['DescripcionOficina'] ? "selected" : "") . '>' . $sucursal['DescripcionOficina'] . '</option>';
                                }
                            }
                            $html .= '</select>';
                            $html .= '</div>';
                            $html .= '</div>';
                        }
                    }
                }
            }
            $html .= '</div>';
            $html .= '</div>';
            $html .= '</div>';
            $html .= '</div>';
            $html .= '</div>';
            $html .= '</div>';

            $this->context->cookie->__set('volumen', $volumen);
            $this->context->cookie->__set('kilos', $kilos);

            return $html; 
        }
        catch(Exception $e)
        {
            $html .= '<div class="row">';
            $html .= '<div class="col px-2">';
            $html .= '<div class="alert alert-danger" role="alert">';
            $html .= 'Ocurrió un error durante la tarificación de los servicios disponibles.';
            $html .= '</div>';
            $html .= '</div>';
            $html .= '</div>';

            $this->errorLogCorreosChile('CorreosChile::CalculateServices - Falló al calcular tarifas de servicios  - '.$e->getMessage(), 3, 'Cart - Tarificador', $address->id_customer);
            return $html;
        }        
    }
    //Al seleccionar el método de envío, guardamos las el servicio y la sucursal seleccionada.
    public function hookActionCarrierProcess($params)
    {
        if($params['cart']->id_carrier){
            $selectedCarrierId = $params['cart']->id_carrier;
            $carrierId = Configuration::get('CORREOSCHILE_CARRIER_ID');
            if(strval($selectedCarrierId) === $carrierId){
                $servicios = tblServicios::servicioSucursal();
                foreach ($servicios as $servicio) {
                    $esSucursal[$servicio['codigoServicio']] = $servicio['codigoServicio'];
                }
                $servicio = filter_input(INPUT_POST, 'correoschile_servicio');
                $sucursal = filter_input(INPUT_POST, 'correoschile_sucursal_'.$servicio);
                if(isset($servicio)){
                    $this->context->cookie->__set('correoschile_servicio', $servicio);
                    if(array_key_exists($servicio, $esSucursal)){
                        $this->context->cookie->__set('correoschile_sucursal', $sucursal);
                        $this->context->cookie->write();
                    }else{
                        $this->context->cookie->__set('correoschile_sucursal', null);
                        $this->context->cookie->write();
                    }
                }
            }
        }
    }

    /**
     * Guarda en correoschile_envios
     * @var Object carrier
     * [id_reference] - Identificador permanente del carrier
     */
    public function hookOrderConfirmation($params)
    {
        $current_cch_carrier        = $this->currentCorreosChileCarrier();
        $ref_current_cch_carrier    = $current_cch_carrier[0]['id_reference'];
        $id_current_cch_carrier     = $current_cch_carrier[0]['id_carrier'];
        $cch_carrier                = new Carrier((int) Configuration::get('CORREOSCHILE_CARRIER_ID'));
        $order_carrier              = new Carrier((int) $params['order']->id_carrier);

        if($order_carrier->id_reference == $ref_current_cch_carrier)
        {
            if(Configuration::get('CORREOSCHILE_CARRIER_ID') === $params['order']->id_carrier){ 
                tblEnvios::guardarEnvio($params['cookie'], $params['order']->id);
            }else if(Configuration::get('CORREOSCHILE_CARRIER_ID') !== $params['order']->id_carrier){
                $this->errorLogCorreosChile('CorreosChile::DatabaseInsert - No se ha podido insertar el pedido en Correoschile_Envios - Transportistas con distinto identificador - [ID transportista configuraciones] : '.Configuration::get('CORREOSCHILE_CARRIER_ID').' | '.'[ID transportista prestashop]  : '.$params['order']->id_carrier, 3,'Cart', (int) $params['order']->id_cart);
            }else{
                $this->errorLogCorreosChile('CorreosChile::DatabaseInsert - No se ha podido insertar el pedido en Correoschile_Envios - Error', 3, 'Cart', (int) $params['order']->id_cart);
            }
        }
    }
    //Agregar archivos CSS y JavaScript necesarios en el Back Office.
    public function hookBackOfficeHeader()
    {
        if (Tools::getValue('module_name') == $this->name) {
            $this->context->controller->addJS($this->_path.'views/js/back.js');
            $this->context->controller->addCSS($this->_path.'views/css/back.css');
        }
    }
    //Actualiza carrier id de configuraciones por id de transportista
    public function hookActionCarrierUpdate($params)
    {
        $carrier = new Carrier((int)(Configuration::get('CORREOSCHILE_CARRIER_ID')));
        if ($params['carrier']->id_reference == $carrier->id_reference) {
            Configuration::updateValue('CORREOSCHILE_CARRIER_ID', (int)$params['carrier']->id);
        }
    }
    //Filtros envios correoschile en panel de administracion
    public function getEnviosCorreos()
    {
        $idPedido       = Tools::getValue("idPedido");
        $numeroEnvio    = Tools::getValue("numeroEnvio");
        $hora_desde     = Tools::getValue("hora_desde");
        $hora_hasta     = Tools::getValue("hora_hasta");
        $estado         = Tools::getValue("estado");
        $conEtiqueta    = Tools::getValue("conEtiqueta");
        $conRetiro      = Tools::getValue("conRetiro");
        $order          = new Order((int) $idPedido);
        $customer       = new Customer($order->id_customer);

        if(isset($conRetiro) || !empty($conRetiro) || $conRetiro =='reset'){

            $envios = tblEnvios::reinicializarFiltros();
        }
        if(!empty($idPedido) || !empty($numeroEnvio) || !empty($hora_desde) || !empty($hora_hasta) || $conEtiqueta==1 || !empty($estado) || $conRetiro==1){

            $envios = tblEnvios::filtrarEnvios($idPedido,$numeroEnvio,$hora_desde,$hora_hasta,$conEtiqueta,$conRetiro,$estado);           
        }

        $html = '';

        if(empty($envios)){
            $html .= '<tr>
            <td class="list-empty" colspan="8">
            <div class="list-empty-msg"><i class="icon-warning-sign list-empty-icon"></i>Ningún registro encontrado</div></td>
            </tr>';
        }else{
            foreach($envios as $key => $envio){
                $id[] = $envio['idPedido'];
            }
            $pedidos    = str_replace('"','',str_replace(array( '[', ']' ), '', json_encode($id)));
            $envios     = tblEnvios::info_enviosFiltrados($pedidos);
            $servicios  = tblServicios::listarNombresServicios();
            foreach($servicios as $values){
                $servicio[$values['codigoServicio']] = $values['descripcion'];
            }
            foreach($envios as $envio)
            {
                $extension  ='pdf';
                if($envio['formatoEtiqueta'] === 'ZPL'){ $extension = 'txt'; } 
                $html .= '<tr class="  odd">
                <td><label><input type="checkbox" class="correosCheck" id="checkboxCorreos_'.$envio['idPedido'].'" value="'.$envio['idPedido'].'"><i class="md-checkbox-control"></i></label></td>
                    <td>'.$envio['idPedido'].'</td>
                    <td id="linkupdate" class="user_info customer_orders_'.$envio['id_customer'].'" data-toggle="modal" data-target="#editar_usuarioModal" data-id="'.$envio['idPedido'].'"><a href="#"><strong>'.$envio['firstname'].'&nbsp;'.$envio['lastname'].'</strong></a></td>
                    <td>'.$envio['fechaCreacion'].'</td>
                    <td>'.$servicio[$envio['codigoServicio']].' '.($envio['nombreSucursal'] !== '' ? '('.$envio['nombreSucursal'].')' : '').'</td>
                    <td>'.Tools::displayPrice($envio['total_shipping'],Context::getContext()->currency).'</td>
                    <td>'.$envio['name'].'</td>
                    <td id="link_'.$envio['idPedido'].'">'.(is_null($envio['numeroEnvio']) ? '-' : ('<a href="'._PS_BASE_URL_.'/upload/correoschile/etiquetas/'.$envio['numeroEnvio'].'.'.$extension. '" target="blank"><strong>'.$envio['numeroEnvio'].'</strong></a>')).'</td>
                    <td id="retiro_'.$envio['idPedido'].'"><p id="msg_retiro_'.$envio['idPedido'].'">'.$envio['fechaRetiro'].'&nbsp;'.$envio['horaRetiroDesde'].'&nbsp;'.$envio['horaRetiroHasta'].'</p></td>
                    <td id="error_'.$envio['idPedido'].'"><p id="msg_error_'.$envio['idPedido'].'">'.$envio['error'].'</td>
                    </tr>';
            }
        }        
        return $html;            
    }
   
    public function validaDireccion()
    {
        $direccion = Tools::getValue("direccion").'. '.Tools::getValue("direccion_2");
        $comuna = Tools::getValue("comuna");
        $codigo_postal = apiNormalizacion::normalizarDireccion($direccion, $comuna);

        return json_encode($codigo_postal);
    }
    public function actualizaCliente()
    {
        $id = Tools::getValue("orderid");
        $envios = tblEnvios::info_enviosFiltrados($id);
        $address = new Address($envios[0]['id_address']);

        return json_encode($envios[0]);
    }
    public function actualizarCliente()
    {
        try{
            
            $id = Tools::getValue("orderid");
            $nombre = Tools::getValue("nombre");
            $comuna = Tools::getValue("comuna");
            $customer = Tools::getValue("customer");
            $apellido = Tools::getValue("apellido");
            $telefono = Tools::getValue("telefono");
            $direccion = Tools::getValue("direccion");
            $direccion_2 = Tools::getValue("direccion_2");
            $sucursal =  Tools::getValue("sucursal");
            $codigo_postal = Tools::getValue("codigo_postal");
            $observaciones = Tools::getValue("observaciones");
            $servicio = Tools::getValue("servicio");

            $normalizacion = apiNormalizacion::normalizarDireccion($direccion, $comuna);
            $normalizado = $normalizacion->CodigoPostal;
            $tipoServicio = tblServicios::tipoServicio($servicio);

            if(empty($nombre)) throw new Exception('Campo nombre no puede estar vacío');            
            if(empty($apellido)) throw new Exception('Campo apellido no puede estar vacío');      
            if(empty($direccion)) throw new Exception('Campo dirección no puede estar vacío');
            if(empty($servicio)) throw new Exception('Debe seleccionar un servicio');
            if($tipoServicio['esSucursal'] == true){
                if(empty($sucursal)) throw new Exception('Debe seleccionar una sucursal');
            }else{
                if($codigo_postal !== $normalizado) throw new Exception('Código postal incorrecto');   
            }

            $sql = 'UPDATE '._DB_PREFIX_.'address a 
            JOIN '._DB_PREFIX_.'orders o ON a.id_address = o.id_address_delivery
            JOIN '._DB_PREFIX_.'correoschile_envios ce ON ce.idPedido = o.id_order
            SET a.firstname="'.$nombre.'",
                a.lastname="'.$apellido.'",
                a.phone="'.$telefono.'",
                a.address1="'.$direccion.'",
                ce.nombreSucursal="'.$sucursal.'",
                a.city="'.$comuna.'",
                a.address2="'.$direccion_2.'",
                a.postcode="'.$codigo_postal.'"
            WHERE ce.idPedido="'.$id.'"';
            Db::getInstance()->Execute($sql);
            Db::getInstance()->update('correoschile_envios', array('observaciones2' => $observaciones , 'codigoServicio' => $servicio),'idPedido='.(int)$id); 
            
            header('http/1.1 200 OK');
            header('Content-Type: application/json; charset=UTF8');
            echo json_encode(array('message'=>'Registro actualizado exitosamente!'));
            exit();

        }catch(Exception $e){
            $this->errorLogCorreosChile('CorreosChile::UpdateClient - Falló al actualizar datos de cliente - '.$e->getMessage(), 3, 'Cart - Tarificador', $id);
            header('http/1.1 500 Internal Server Error');
            header('Content-Type: application/json; charset=UTF8');
            die(json_encode(array('message'=>$e->getMessage())));
        }
    }
    public function currentCorreosChileCarrier()
    {
        $sql = 'SELECT id_carrier, id_reference FROM '._DB_PREFIX_.'carrier WHERE active = 1 AND deleted = 0 AND external_module_name = "'.$this->name.'"';
        return Db::getInstance()->ExecuteS($sql);
    }
    public function errorLogCorreosChile($mensaje, $tipo, $step, $id)    
    {
        PrestaShopLogger::addLog($mensaje, $tipo, null, $step, $id, true);
    }
}
