<?php
class ApiComuna
{
    public static function listarComunasSegunRegion($codigoRegion)
    {
        $wsdl = trim(Configuration::get('CORREOSCHILE_WS_COMUNA'));
        if($wsdl !== '' && substr_compare(strtolower($wsdl), '?wsdl', -strlen('?wsdl')) < 0) 
        {
            $wsdl .= '?wsdl';
        }
        try 
        {
            $client = new SoapClient($wsdl, array('trace' => 1, 'exception' => 0));
            $result = $client->__soapCall('listarComunasSegunRegion', array(
                'listarComunasSegunRegion' => array(
                    'usuario' => trim(Configuration::get('CORREOSCHILE_USUARIO_API')),
                    'contrasena' => trim(Configuration::get('CORREOSCHILE_CONTRASENA_API')),
                    'codigoRegion' => $codigoRegion
                )), null, null);
            return $result->listarComunasSegunRegionResult->ComunaTO;
        } 
        catch (SoapFault $e) 
        {
            throw new Exception($e->getMessage(), 0, $e);
        } 
        catch (Exception $e) 
        {
            throw new Exception('Ocurio un errror intentando obtener las comunas según región.', 0, $e);
        }
    }
    
    public static function listarTodasLasComunas()
    {
        $wsdl = trim(Configuration::get('CORREOSCHILE_WS_COMUNA'));
        if($wsdl !== '' && substr_compare(strtolower($wsdl), '?wsdl', -strlen('?wsdl')) < 0){
            $wsdl .= '?wsdl';
        }
        try
        {
            $client = new SoapClient($wsdl, array('trace' => 1, 'exception' => 0));
            $result = $client->__soapCall('listarTodasLasComunas', array(
                'listarTodasLasComunas' => array(
                    'usuario' => trim(Configuration::get('CORREOSCHILE_USUARIO_API')),
                    'contrasena' => trim(Configuration::get('CORREOSCHILE_CONTRASENA_API'))
                )), null, null);
            return $result->listarTodasLasComunasResult->ComunaTO;
        }
        catch (Exception $e) {
            throw new Exception('Ocurio un errror intentando obtener las comunas.', 0, $e);
        }
    }
    
    public static function obtenerComunaPorNombre($nombreComuna)
    {
        $comunaEncontrada = null;
        try
        {
            $comunaEncontrada = null;
            $comunas = ApiComuna::listarTodasLasComunas();
            foreach($comunas as $comuna){
                if(strtolower($comuna->NombreComuna) !== strtolower($nombreComuna)) {
                    continue;
                }
                $comunaEncontrada = $comuna;
                break;
            }
        } catch (Exception $ex) {
            $comunaEncontrada = null;
        }
        return $comunaEncontrada; 
    }
    
     /**
     * Get a iso code with its id state.
     *
     * @param string $id_state id state
     *
     * @return string Ico code 
     */
    public static function getIsoCodeByIdState($id_state, $idCountry = null)
    {
        return Db::getInstance()->getValue('
		SELECT `iso_code`
		FROM `' . _DB_PREFIX_ . 'state`
		WHERE `id_state` = \'' . pSQL($id_state) . '\'
		' . ($idCountry ? 'AND `id_country` = ' . (int) $idCountry : ''));
    }

    public static function jsonComunas() {
        $arrayComunas = array(
            array('idRegion' => 'CL-TA', 'idComuna' => 'AHO', 'Comuna' => 'ALTO HOSPICIO'),
            array('idRegion' => 'CL-TA', 'idComuna' => 'CMR', 'Comuna' => 'CAMIÑA'),
            array('idRegion' => 'CL-TA', 'idComuna' => 'CCH', 'Comuna' => 'COLCHANE'),
            array('idRegion' => 'CL-TA', 'idComuna' => 'HRA', 'Comuna' => 'HUARA'),
            array('idRegion' => 'CL-TA', 'idComuna' => 'IQQ', 'Comuna' => 'IQUIQUE'),
            array('idRegion' => 'CL-TA', 'idComuna' => 'OPC', 'Comuna' => 'PICA'),
            array('idRegion' => 'CL-TA', 'idComuna' => 'PAM', 'Comuna' => 'POZO ALMONTE'),
            array('idRegion' => 'CL-AN', 'idComuna' => 'ANF', 'Comuna' => 'ANTOFAGASTA'),
            array('idRegion' => 'CL-AN', 'idComuna' => 'CJC', 'Comuna' => 'CALAMA'),
            array('idRegion' => 'CL-AN', 'idComuna' => 'MAE', 'Comuna' => 'MARIA ELENA'),
            array('idRegion' => 'CL-AN', 'idComuna' => 'MJS', 'Comuna' => 'MEJILLONES'),
            array('idRegion' => 'CL-AN', 'idComuna' => 'OGE', 'Comuna' => 'OLLAGUE'),
            array('idRegion' => 'CL-AN', 'idComuna' => 'SPX', 'Comuna' => 'SAN PEDRO DE ATACAMA'),
            array('idRegion' => 'CL-AN', 'idComuna' => 'SGD', 'Comuna' => 'SIERRA GORDA'),
            array('idRegion' => 'CL-AN', 'idComuna' => 'GTE', 'Comuna' => 'TALTAL'),
            array('idRegion' => 'CL-AN', 'idComuna' => 'TOC', 'Comuna' => 'TOCOPILLA'),
            array('idRegion' => 'CL-AT', 'idComuna' => 'ADC', 'Comuna' => 'ALTO DEL CARMEN'),
            array('idRegion' => 'CL-AT', 'idComuna' => 'CLR', 'Comuna' => 'CALDERA'),
            array('idRegion' => 'CL-AT', 'idComuna' => 'ZHN', 'Comuna' => 'CHAÑARAL'),
            array('idRegion' => 'CL-AT', 'idComuna' => 'CPO', 'Comuna' => 'COPIAPO'),
            array('idRegion' => 'CL-AT', 'idComuna' => 'DAG', 'Comuna' => 'DIEGO DE ALMAGRO'),
            array('idRegion' => 'CL-AT', 'idComuna' => 'FRN', 'Comuna' => 'FREIRINA'),
            array('idRegion' => 'CL-AT', 'idComuna' => 'HCO', 'Comuna' => 'HUASCO'),
            array('idRegion' => 'CL-AT', 'idComuna' => 'TRM', 'Comuna' => 'TIERRA AMARILLA'),
            array('idRegion' => 'CL-AT', 'idComuna' => 'VLR', 'Comuna' => 'VALLENAR'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'JAB', 'Comuna' => 'ANDACOLLO'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'CLL', 'Comuna' => 'CANELA'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'COB', 'Comuna' => 'COMBARBALA'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'COQ', 'Comuna' => 'COQUIMBO'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'ILL', 'Comuna' => 'ILLAPEL'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'LHI', 'Comuna' => 'LA HIGUERA'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'LSC', 'Comuna' => 'LA SERENA'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'LV7', 'Comuna' => 'LOS VILOS'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'MPC', 'Comuna' => 'MONTE PATRIA'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'OVL', 'Comuna' => 'OVALLE'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'PIO', 'Comuna' => 'PAIGUANO'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'PTQ', 'Comuna' => 'PUNITAQUI'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'RHO', 'Comuna' => 'RIO HURTADO'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'SCA', 'Comuna' => 'SALAMANCA'),
            array('idRegion' => 'CL-CO', 'idComuna' => 'VCA', 'Comuna' => 'VICUÑA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'ABO', 'Comuna' => 'ALGARROBO'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'CDO', 'Comuna' => 'CABILDO'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'LC7', 'Comuna' => 'CALERA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'CLG', 'Comuna' => 'CALLE LARGA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'CRT', 'Comuna' => 'CARTAGENA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'ZCB', 'Comuna' => 'CASABLANCA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'CAT', 'Comuna' => 'CATEMU'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'GKF', 'Comuna' => 'CONCON'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'EQO', 'Comuna' => 'EL QUISCO'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'ETB', 'Comuna' => 'EL TABO'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'HJA', 'Comuna' => 'HIJUELAS'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'IPC', 'Comuna' => 'ISLA DE PASCUA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'IJF', 'Comuna' => 'JUAN FERNANDEZ'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'LCR', 'Comuna' => 'LA CRUZ'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'LLC', 'Comuna' => 'LA LIGUA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'LIC', 'Comuna' => 'LIMACHE'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'GRK', 'Comuna' => 'LLAILLAY'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'LAC', 'Comuna' => 'LOS ANDES'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'NOG', 'Comuna' => 'NOGALES'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'OLM', 'Comuna' => 'OLMUE'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'PQE', 'Comuna' => 'PANQUEHUE'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'PPO', 'Comuna' => 'PAPUDO'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'PTK', 'Comuna' => 'PETORCA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'PCV', 'Comuna' => 'PUCHUNCAVI'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'PUT', 'Comuna' => 'PUTAENDO'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'QTA', 'Comuna' => 'QUILLOTA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'QPE', 'Comuna' => 'QUILPUE'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'QTO', 'Comuna' => 'QUINTERO'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'RDL', 'Comuna' => 'RINCONADA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'QTN', 'Comuna' => 'SAN ANTONIO'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'ZEB', 'Comuna' => 'SAN ESTEBAN'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'SFP', 'Comuna' => 'SAN FELIPE'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'GQX', 'Comuna' => 'SANTA MARIA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'SDQ', 'Comuna' => 'SANTO DOMINGO'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'VAP', 'Comuna' => 'VALPARAISO'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'VIA', 'Comuna' => 'VILLA ALEMANA'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'KNA', 'Comuna' => 'VIÑA DEL MAR'),
            array('idRegion' => 'CL-VS', 'idComuna' => 'JJG', 'Comuna' => 'ZAPALLAR'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'ZHE', 'Comuna' => 'CHEPICA'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'CHB', 'Comuna' => 'CHIMBARONGO'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'CGY', 'Comuna' => 'CODEGUA'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'CNO', 'Comuna' => 'COINCO'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'CTO', 'Comuna' => 'COLTAUCO'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'RDD', 'Comuna' => 'DOÑIHUE'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'GRA', 'Comuna' => 'GRANEROS'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'LEA', 'Comuna' => 'LA ESTRELLA'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'LCB', 'Comuna' => 'LAS CABRAS'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'LEC', 'Comuna' => 'LITUECHE'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'LLL', 'Comuna' => 'LOLOL'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'MCH', 'Comuna' => 'MACHALI'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'ZML', 'Comuna' => 'MALLOA'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'MCG', 'Comuna' => 'MARCHIHUE'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'SFM', 'Comuna' => 'MOSTAZAL'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'ZGA', 'Comuna' => 'NANCAGUA'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'NVD', 'Comuna' => 'NAVIDAD'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'OAL', 'Comuna' => 'OLIVAR'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'PLA', 'Comuna' => 'PALMILLA'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'PDS', 'Comuna' => 'PAREDONES'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'PSF', 'Comuna' => 'PERALILLO'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'PEO', 'Comuna' => 'PEUMO'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'PDG', 'Comuna' => 'PICHIDEGUA'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'PMU', 'Comuna' => 'PICHILEMU'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'PSO', 'Comuna' => 'PLACILLA'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'PNQ', 'Comuna' => 'PUMANQUE'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'QCC', 'Comuna' => 'QUINTA DE TILCOCO'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'QRC', 'Comuna' => 'RANCAGUA'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'RGO', 'Comuna' => 'RENGO'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'REQ', 'Comuna' => 'REQUINOA'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'SF7', 'Comuna' => 'SAN FERNANDO'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'SVT', 'Comuna' => 'SAN VICENTE'),
            array('idRegion' => 'CL-LI', 'idComuna' => 'ZSC', 'Comuna' => 'SANTA CRUZ'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'CQE', 'Comuna' => 'CAUQUENES'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'CHA', 'Comuna' => 'CHANCO'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'CLB', 'Comuna' => 'COLBUN'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'CTT', 'Comuna' => 'CONSTITUCION'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'CEP', 'Comuna' => 'CUREPTO'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'ZCQ', 'Comuna' => 'CURICO'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'EPD', 'Comuna' => 'EMPEDRADO'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'HLE', 'Comuna' => 'HUALAÑE'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'LNN', 'Comuna' => 'LICANTEN'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'ZLR', 'Comuna' => 'LINARES'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'LGV', 'Comuna' => 'LONGAVI'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'ZMA', 'Comuna' => 'MAULE'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'ZMO', 'Comuna' => 'MOLINA'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'PRR', 'Comuna' => 'PARRAL'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'PLO', 'Comuna' => 'PELARCO'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'PLE', 'Comuna' => 'PELLUHUE'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'PNH', 'Comuna' => 'PENCAHUE'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'RAU', 'Comuna' => 'RAUCO'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'RTO', 'Comuna' => 'RETIRO'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'RRO', 'Comuna' => 'RIO CLARO'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'RML', 'Comuna' => 'ROMERAL'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'SAF', 'Comuna' => 'SAGRADA FAMILIA'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'SCQ', 'Comuna' => 'SAN CLEMENTE'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'SJA', 'Comuna' => 'SAN JAVIER'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'GIP', 'Comuna' => 'SAN RAFAEL'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'TLX', 'Comuna' => 'TALCA'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'TEN', 'Comuna' => 'TENO'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'VCH', 'Comuna' => 'VICHUQUEN'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'VGE', 'Comuna' => 'VILLA ALEGRE'),
            array('idRegion' => 'CL-ML', 'idComuna' => 'YBB', 'Comuna' => 'YERBAS BUENAS'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'LAS', 'Comuna' => 'ALTO BIOBIO'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'AUO', 'Comuna' => 'ANTUCO'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'ARA', 'Comuna' => 'ARAUCO'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'CRO', 'Comuna' => 'CABRERO'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'FWN', 'Comuna' => 'CAÑETE'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'CYE', 'Comuna' => 'CHIGUAYANTE'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'CCP', 'Comuna' => 'CONCEPCION'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'CTM', 'Comuna' => 'CONTULMO'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'KQQ', 'Comuna' => 'CORONEL'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'CNE', 'Comuna' => 'CURANILAHUE'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'FRD', 'Comuna' => 'FLORIDA'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'HSP', 'Comuna' => 'HUALPEN'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'KQL', 'Comuna' => 'HUALQUI'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'LLJ', 'Comuna' => 'LAJA'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'ZLB', 'Comuna' => 'LEBU'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'ZAO', 'Comuna' => 'LOS ALAMOS'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'LSQ', 'Comuna' => 'LOS ANGELES'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'LOT', 'Comuna' => 'LOTA'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'MUL', 'Comuna' => 'MULCHEN'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'NAC', 'Comuna' => 'NACIMIENTO'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'NRE', 'Comuna' => 'NEGRETE'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'PCO', 'Comuna' => 'PENCO'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'QCO', 'Comuna' => 'QUILACO'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'QEO', 'Comuna' => 'QUILLECO'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'SPZ', 'Comuna' => 'SAN PEDRO DE LA PAZ'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'SRO', 'Comuna' => 'SAN ROSENDO'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'SBB', 'Comuna' => 'SANTA BARBARA'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'SAJ', 'Comuna' => 'SANTA JUANA'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'ZTO', 'Comuna' => 'TALCAHUANO'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'TRU', 'Comuna' => 'TIRUA'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'TMC', 'Comuna' => 'TOME'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'TAL', 'Comuna' => 'TUCAPEL'),
            array('idRegion' => 'CL-BI', 'idComuna' => 'JFF', 'Comuna' => 'YUMBEL'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'ZOL', 'Comuna' => 'ANGOL'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'CRH', 'Comuna' => 'CARAHUE'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'ZHL', 'Comuna' => 'CHOLCHOL'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'CPI', 'Comuna' => 'COLLIPULLI'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'CUC', 'Comuna' => 'CUNCO'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'CCC', 'Comuna' => 'CURACAUTIN'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'CRE', 'Comuna' => 'CURARREHUE'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'ECA', 'Comuna' => 'ERCILLA'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'FIE', 'Comuna' => 'FREIRE'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'GAO', 'Comuna' => 'GALVARINO'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'GEA', 'Comuna' => 'GORBEA'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'LTR', 'Comuna' => 'LAUTARO'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'LOC', 'Comuna' => 'LONCOCHE'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'LQY', 'Comuna' => 'LONQUIMAY'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'SUS', 'Comuna' => 'LOS SAUCES'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'LMO', 'Comuna' => 'LUMACO'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'MPO', 'Comuna' => 'MELIPEUCO'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'NIP', 'Comuna' => 'NUEVA IMPERIAL'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'PLC', 'Comuna' => 'PADRE LAS CASAS'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'PQO', 'Comuna' => 'PERQUENCO'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'PQN', 'Comuna' => 'PITRUFQUEN'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'ZPU', 'Comuna' => 'PUCON'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'PUR', 'Comuna' => 'PUREN'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'RNA', 'Comuna' => 'RENAICO'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'PSA', 'Comuna' => 'SAAVEDRA'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'ZCO', 'Comuna' => 'TEMUCO'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'TSC', 'Comuna' => 'TEODORO SCHMIDT'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'NTN', 'Comuna' => 'TOLTEN'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'ZEN', 'Comuna' => 'TRAIGUEN'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'VIC', 'Comuna' => 'VICTORIA'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'VLN', 'Comuna' => 'VILCUN'),
            array('idRegion' => 'CL-AR', 'idComuna' => 'VRR', 'Comuna' => 'VILLARRICA'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'ACD', 'Comuna' => 'ANCUD'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'CBU', 'Comuna' => 'CALBUCO'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'CTR', 'Comuna' => 'CASTRO'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'CIT', 'Comuna' => 'CHAITEN'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'CHO', 'Comuna' => 'CHONCHI'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'CHM', 'Comuna' => 'COCHAMO'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'CDV', 'Comuna' => 'CURACO DE VELEZ'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'DLE', 'Comuna' => 'DALCAHUE'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'FSA', 'Comuna' => 'FRESIA'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'FRT', 'Comuna' => 'FRUTILLAR'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'FTF', 'Comuna' => 'FUTALEUFU'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'HLA', 'Comuna' => 'HUALAIHUE'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'LLQ', 'Comuna' => 'LLANQUIHUE'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'LMM', 'Comuna' => 'LOS MUERMOS'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'MAU', 'Comuna' => 'MAULLIN'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'ZOS', 'Comuna' => 'OSORNO'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'FLP', 'Comuna' => 'PALENA'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'PMC', 'Comuna' => 'PUERTO MONTT'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'PCY', 'Comuna' => 'PUERTO OCTAY'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'ZPV', 'Comuna' => 'PUERTO VARAS'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'PQU', 'Comuna' => 'PUQUELDON'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'PRE', 'Comuna' => 'PURRANQUE'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'LOO', 'Comuna' => 'PUYEHUE'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'QIL', 'Comuna' => 'QUEILEN'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'QLO', 'Comuna' => 'QUELLON'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'QMC', 'Comuna' => 'QUEMCHI'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'QHO', 'Comuna' => 'QUINCHAO'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'RNC', 'Comuna' => 'RIO NEGRO'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'SJC', 'Comuna' => 'SAN JUAN DE LA COSTA'),
            array('idRegion' => 'CL-LL', 'idComuna' => 'SPL', 'Comuna' => 'SAN PABLO'),
            array('idRegion' => 'CL-AI', 'idComuna' => 'WPA', 'Comuna' => 'AYSEN'),
            array('idRegion' => 'CL-AI', 'idComuna' => 'CLH', 'Comuna' => 'CHILE CHICO'),
            array('idRegion' => 'CL-AI', 'idComuna' => 'GRL', 'Comuna' => 'CISNES'),
            array('idRegion' => 'CL-AI', 'idComuna' => 'GKL', 'Comuna' => 'COCHRANE'),
            array('idRegion' => 'CL-AI', 'idComuna' => 'GXQ', 'Comuna' => 'COYHAIQUE'),
            array('idRegion' => 'CL-AI', 'idComuna' => 'GTS', 'Comuna' => 'GUAITECAS'),
            array('idRegion' => 'CL-AI', 'idComuna' => 'LVE', 'Comuna' => 'LAGO VERDE'),
            array('idRegion' => 'CL-AI', 'idComuna' => 'VOS', 'Comuna' => 'OHIGGINS'),
            array('idRegion' => 'CL-AI', 'idComuna' => 'RIZ', 'Comuna' => 'RIO IBAÑEZ'),
            array('idRegion' => 'CL-AI', 'idComuna' => 'CTL', 'Comuna' => 'TORTEL'),
            array('idRegion' => 'CL-MA', 'idComuna' => 'LTH', 'Comuna' => 'ANTARTICA'),
            array('idRegion' => 'CL-MA', 'idComuna' => 'LTJ', 'Comuna' => 'CABO DE HORNOS'),
            array('idRegion' => 'CL-MA', 'idComuna' => 'LGB', 'Comuna' => 'LAGUNA BLANCA'),
            array('idRegion' => 'CL-MA', 'idComuna' => 'PNT', 'Comuna' => 'NATALES'),
            array('idRegion' => 'CL-MA', 'idComuna' => 'ZPR', 'Comuna' => 'PORVENIR'),
            array('idRegion' => 'CL-MA', 'idComuna' => 'PVA', 'Comuna' => 'PRIMAVERA'),
            array('idRegion' => 'CL-MA', 'idComuna' => 'PUQ', 'Comuna' => 'PUNTA ARENAS'),
            array('idRegion' => 'CL-MA', 'idComuna' => 'RVE', 'Comuna' => 'RIO VERDE'),
            array('idRegion' => 'CL-MA', 'idComuna' => 'IUT', 'Comuna' => 'SAN GREGORIO'),
            array('idRegion' => 'CL-MA', 'idComuna' => 'TMK', 'Comuna' => 'TIMAUKEL'),
            array('idRegion' => 'CL-MA', 'idComuna' => 'TDP', 'Comuna' => 'TORRES DEL PAINE'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'VAH', 'Comuna' => 'ALHUE'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'BUI', 'Comuna' => 'BUIN'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'ZCT', 'Comuna' => 'CALERA DE TANGO'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FCV', 'Comuna' => 'CERRILLOS'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FCW', 'Comuna' => 'CERRO NAVIA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'GEG', 'Comuna' => 'COLINA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FCX', 'Comuna' => 'CONCHALI'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'CVI', 'Comuna' => 'CURACAVI'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'EBQ', 'Comuna' => 'EL BOSQUE'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'EMT', 'Comuna' => 'EL MONTE'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FCY', 'Comuna' => 'ESTACION CENTRAL'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FCZ', 'Comuna' => 'HUECHURABA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDA', 'Comuna' => 'INDEPENDENCIA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'GEK', 'Comuna' => 'ISLA DE MAIPO'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDB', 'Comuna' => 'LA CISTERNA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDD', 'Comuna' => 'LA FLORIDA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDE', 'Comuna' => 'LA GRANJA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'LPT', 'Comuna' => 'LA PINTANA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDF', 'Comuna' => 'LA REINA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'LSG', 'Comuna' => 'LAMPA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDG', 'Comuna' => 'LAS CONDES'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDH', 'Comuna' => 'LO BARNECHEA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'LEJ', 'Comuna' => 'LO ESPEJO'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDI', 'Comuna' => 'LO PRADO'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDJ', 'Comuna' => 'MACUL'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDK', 'Comuna' => 'MAIPU'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'MAO', 'Comuna' => 'MARIA PINTO'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'MPA', 'Comuna' => 'MELIPILLA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDL', 'Comuna' => 'ÑUÑOA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'PHT', 'Comuna' => 'PADRE HURTADO'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'GEJ', 'Comuna' => 'PAINE'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'PAC', 'Comuna' => 'PEDRO AGUIRRE CERDA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'GSI', 'Comuna' => 'PEÑAFLOR'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDY', 'Comuna' => 'PEÑALOLEN'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'PIR', 'Comuna' => 'PIRQUE'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDN', 'Comuna' => 'PROVIDENCIA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDO', 'Comuna' => 'PUDAHUEL'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'PTA', 'Comuna' => 'PUENTE ALTO'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'QRA', 'Comuna' => 'QUILICURA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDP', 'Comuna' => 'QUINTA NORMAL'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDQ', 'Comuna' => 'RECOLETA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'REA', 'Comuna' => 'RENCA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'SBD', 'Comuna' => 'SAN BERNARDO'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDR', 'Comuna' => 'SAN JOAQUIN'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'SJS', 'Comuna' => 'SAN JOSE DE MAIPO'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDS', 'Comuna' => 'SAN MIGUEL'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'ZPM', 'Comuna' => 'SAN PEDRO'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDU', 'Comuna' => 'SAN RAMON'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'SCL', 'Comuna' => 'SANTIAGO'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'TFI', 'Comuna' => 'SIN INFORMACION COMUNA'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'TNT', 'Comuna' => 'TALAGANTE'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'EXI', 'Comuna' => 'TILTIL'),
            array('idRegion' => 'CL-RM', 'idComuna' => 'FDW', 'Comuna' => 'VITACURA'),
            array('idRegion' => 'CL-AP', 'idComuna' => 'ARI', 'Comuna' => 'ARICA'),
            array('idRegion' => 'CL-AP', 'idComuna' => 'CRS', 'Comuna' => 'CAMARONES'),
            array('idRegion' => 'CL-AP', 'idComuna' => 'GLG', 'Comuna' => 'GENERAL LAGOS'),
            array('idRegion' => 'CL-AP', 'idComuna' => 'PTR', 'Comuna' => 'PUTRE'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'CRC', 'Comuna' => 'CORRAL'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'FTO', 'Comuna' => 'FUTRONO'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'ZLU', 'Comuna' => 'LA UNION'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'LRC', 'Comuna' => 'LAGO RANCO'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'LNC', 'Comuna' => 'LANCO'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'LAG', 'Comuna' => 'LOS LAGOS'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'MFL', 'Comuna' => 'MAFIL'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'LGM', 'Comuna' => 'MARIQUINA'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'PAI', 'Comuna' => 'PAILLACO'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'PGP', 'Comuna' => 'PANGUIPULLI'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'RBN', 'Comuna' => 'RIO BUENO'),
            array('idRegion' => 'CL-LR', 'idComuna' => 'ZAL', 'Comuna' => 'VALDIVIA'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'BLN', 'Comuna' => 'BULNES'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'YAI', 'Comuna' => 'CHILLAN'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'CVO', 'Comuna' => 'CHILLAN VIEJO'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'CBR', 'Comuna' => 'COBQUECURA'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'CEU', 'Comuna' => 'COELEMU'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'CUH', 'Comuna' => 'COIHUECO'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'GJR', 'Comuna' => 'EL CARMEN'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'NNH', 'Comuna' => 'NINHUE'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'NQN', 'Comuna' => 'ÑIQUEN'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'PMO', 'Comuna' => 'PEMUCO'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'PNO', 'Comuna' => 'PINTO'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'PZO', 'Comuna' => 'PORTEZUELO'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'QLL', 'Comuna' => 'QUILLON'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'QRH', 'Comuna' => 'QUIRIHUE'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'RQL', 'Comuna' => 'RANQUIL'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'SCS', 'Comuna' => 'SAN CARLOS'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'SFA', 'Comuna' => 'SAN FABIAN'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'GIY', 'Comuna' => 'SAN IGNACIO'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'SNL', 'Comuna' => 'SAN NICOLAS'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'THC', 'Comuna' => 'TREGUACO'),
            array('idRegion' => 'CL-NB', 'idComuna' => 'YGY', 'Comuna' => 'YUNGAY')
        );
        $json = json_decode(json_encode($arrayComunas));
        return $json;
    }
}
