<?php

require_once 'utilidades.php';

class ApiTarificacion
{
    public static function consultaCobertura($comunaRemitente, $comunaDestinatario, $kilos, $volumen)
    {
        $comunaRemitente = utilidades::QuitarAcentos($comunaRemitente);
        $comunaDestinatario = utilidades::QuitarAcentos($comunaDestinatario);

        $wsdl = trim(Configuration::get('CORREOSCHILE_WS_TARIFICACION'));
        if($wsdl !== '' && substr_compare(strtolower($wsdl), '?wsdl', -strlen('?wsdl')) < 0){
            $wsdl .= '?wsdl';
        }
        
        try
        {
            $client = new SoapClient($wsdl, array('trace' => 1, 'exception' => 0));
            $result = $client->__soapCall('consultaCobertura', array(
                'consultaCobertura' => array(
                    'usuario' => trim(Configuration::get('CORREOSCHILE_USUARIO_API')), 
                    'contrasena' => trim(Configuration::get('CORREOSCHILE_CONTRASENA_API')),
                    'consultaCobertura' => array(
                        'CodigoPostalDestinatario' => '',
                        'CodigoPostalRemitente' => '',
                        'ComunaDestino' => $comunaDestinatario, 
                        'ComunaRemitente' => $comunaRemitente, 
                        'ImporteReembolso' => '',
                        'ImporteValorAsegurado' => '',
                        'Kilos' => $kilos,
                        'NumeroTotalPieza' => '1',
                        'PaisDestinatario' => '056',
                        'PaisRemitente' => '056',
                        'TipoPortes' => 'P',
                        'Volumen' => $volumen
                    )
                )), null, null);
            return json_decode(json_encode($result->consultaCoberturaResult->ServicioTO));
        }
        catch (SoapFault $e) {
            throw new Exception($e->getMessage(), 0, $e);
        }
        catch (Exception $e) {
            throw new Exception('Ocurrio un error intentando obtener las coberturas.', 0, $e);
        }
    }
    
    public static function consultaCoberturaPorProducto($codigoServicio, $comunaRemitente, $comunaDestinatario, $kilos, $volumen)
    {
        $comunaRemitente = utilidades::QuitarAcentos($comunaRemitente);
        $comunaDestinatario = utilidades::QuitarAcentos($comunaDestinatario);

        $wsdl = trim(Configuration::get('CORREOSCHILE_WS_TARIFICACION'));
        if($wsdl !== '' && substr_compare(strtolower($wsdl), '?wsdl', -strlen('?wsdl')) < 0){
            $wsdl .= '?wsdl';
        }
        try
        {
            $client = new SoapClient($wsdl, array('trace' => 1, 'exception' => 0));
            $result = $client->__soapCall('consultaCoberturaPorProducto', array(
                'consultaCoberturaPorProducto' => array(
                    'usuario' => trim(Configuration::get('CORREOSCHILE_USUARIO_API')), 
                    'contrasena' => trim(Configuration::get('CORREOSCHILE_CONTRASENA_API')),
                    'consultaCobertura' => array(
                        'CodigoPostalDestinatario' => '',
                        'CodigoPostalRemitente' => '',
                        'CodigoServicio' => strVal($codigoServicio), 
                        'ComunaDestino' => $comunaDestinatario, 
                        'ComunaRemitente' => $comunaRemitente, 
                        'ImporteReembolso' => '', 
                        'ImporteValorAsegurado' => '', 
                        'Kilos' => $kilos, 
                        'NumeroTotalPieza' => '1', 
                        'PaisDestinatario' => '056', 
                        'PaisRemitente' => '056', 
                        'TipoPortes' => 'P',
                        'Volumen' => $volumen
                    )
                )), null, null);
                
            return $result->consultaCoberturaPorProductoResult;
        }
        catch (SoapFault $e) {
            throw new Exception($e->getMessage(), 0, $e);
        }
        catch (Exception $e) {
            throw new Exception('Ocurrio un error intentando obtener la cobertura por producto.', 0, $e);
        }
    }
    
    public static function totalConsultaCoberturaPorProducto($codigoServicio, $comunaRemitente, $comunaDestinatario, $kilos, $volumen)
    {
       try
       {
           $coberturaPorProducto = ApiTarificacion::consultaCoberturaPorProducto($codigoServicio, $comunaRemitente, $comunaDestinatario, $kilos, $volumen);
           return $coberturaPorProducto->TotalTasacion->Total;
       } 
       catch (Exception $ex) 
       {
           return 0;
       }  
    }

}